'use strict';
var webpack = require('webpack');
var path = require('path');

/**
 * Remove/clean your build folder(s) before building
 */
var CleanWebpackPlugin = require('clean-webpack-plugin');

var ExtractTextPlugin = require('extract-text-webpack-plugin');

module.exports = {
    entry: path.join(__dirname, './src/radio.js'),

    output: {
        path: path.join( __dirname, './dist'),
        filename: "radio.js",
        library: "@whitewizard/radio",
        libraryTarget: "umd",
        umdNamedDefine: true
    },
    module: {
        rules: [
            {
                test: /\.css$/,
                use: ['style-loader', 'css-loader']
            },
            {
                test: /.(ico|png|jpg|gif|svg)(\?.+)?$/,
                use: "url-loader?limit=50000"
            },
            {
                test: /\.js$/,
                exclude: /node_modules/,
                use: "babel-loader"
            },
            {
                test: /\.vue$/,
                loader: 'vue-loader',
                options: {
                    loaders: {
                        sass: ExtractTextPlugin.extract({
                            use: ["css-loader", "sass-loader"]
                        }),
                        scss: ExtractTextPlugin.extract({
                            use: ["css-loader", "sass-loader"]
                        }),
                        css: ExtractTextPlugin.extract({
                            use: ["css-loader"]
                        })
                    }
                }
            }
        ]
    },
    plugins: [
        new ExtractTextPlugin("radio.css"),
        new CleanWebpackPlugin(['dist'], {
            root: process.cwd(),
            verbose: true,
            dry: false
        })
    ]
};
